package com.topcoder.persistence.relation;

/**
 * The IncompatibleRelationsException exception is thrown when an operation is
 * called for two relations but the relations don't respect the conditions imposed
 * by that specific operation.
 * 
 * For example, a union operation requires the tuple types of the relations to be identical.
 *
 * Thread safety:
 * 
 * The class is immutable so it is thread safe.
 *
 * @author TCSDESIGNER
 */
public class IncompatibleRelationsException extends OperationException {

    /**
     * Create a new instance ConfigurationException with the given error message.
     *
     * The message is enforced to be completed, so that the user will benefit from meaningful messages.
     *
     * Simply calls the super constructor with the message.
     *
     * @param message the message describing the exception
     *
     * @throws IllegalArgumentException if the message is null
     */
    public IncompatibleRelationsException(String message) throws IllegalArgumentException {
        super(message);
    }

    /**
     * Create a new instance ConfigurationException with the given error message and the given cause.
     *
     * The message is enforced to be completed, so that the user will benefit from meaningful messages.
     *
     * Simply calls the super constructor with the message and cause.
     *
     * @param message the message describing the exception
     * @param cause the cause of the exception
     *
     * @throws IllegalArgumentException if the message is null or if cause is null
     */
    public IncompatibleRelationsException(String message, Throwable cause) throws IllegalArgumentException {
        super(message, cause);
    }

}
