package com.topcoder.persistence.relation;


/**
 * This interface abstracts a constraint applied on a relation.
 * 
 * The interface defines only one method that takes as input a relation and
 * returns a boolean value indicating whether the constraint is met or not.
 * 
 * Thread safety:
 * 
 * The implementations of this class are expected to have no state or be
 * immutable so they should be thread safe.
 * 
 * @author TCSDESIGNER
 */
public interface RelationConstraint {

	/**
	 * Checks whether a relation respects the constraint.
	 * This usually involves iterating each relation tuple.
	 * 
	 * @param relation the relation to check
	 * 
	 * @return true if constraint is met, false otherwise
	 * 
	 * @throws IllegalArgumentException if the argument is null
	 * @throws EvaluationException thrown if the evaluation cannot be done because of an
	 * implementation specific error 
	 */
	public boolean validate(Relation relation) throws IllegalArgumentException, EvaluationException;
	
}
