package com.topcoder.persistence.relation;

/**
 * The RelationPersistence interface abstracts bulk persistence functionality for relations.
 * 
 * This interface defines only two methods, for bulk saving and bulk loading of a relation.
 * The relations are saved and loaded by name. Some implementations might use that
 * (a database implementation might use name as table name) and some may ignore it
 * (the ResultSet and XML implementations for example).
 * 
 * The saving and loading involves the persistence of the tuple type and the tuples.
 * The constraints are not persisted in the default implementations but other
 * implementations may choose to implement that too.
 * 
 * @author TCSDESIGNER
 */
public interface RelationPersistence {
	
	/**
	 * Saves an entire relation to persistence.
	 * 
	 * @param relation the relation to persist
	 * 
	 * @throws IllegalArgumentException if the argument is null
	 * @throws PersistenceException if an implementation specific error has occured
	 */
	public void save(Relation relation) throws IllegalArgumentException, PersistenceException;

	/**
	 * Loads an entire relation from persistence.
	 * 
	 * @param resultRelation the result relation (must be empty and typeless)
	 * 
	 * @throws IllegalArgumentException if the argument is null, empty or all spaces
	 * @throws PersistenceException if an implementation specific error has occured
	 */
	public void load(Relation resultRelation) throws IllegalArgumentException, PersistenceException;

}
