package com.topcoder.persistence.relation.constraints;

import com.topcoder.persistence.relation.EvaluationException;
import com.topcoder.persistence.relation.Tuple;
import com.topcoder.persistence.relation.TupleConstraint;

/**
 * This class represents a tuple constraint that can use any mathematical
 * expression. The expression has of course to result in a boolean result
 * in the end.
 * 
 * This implementation uses the Math Expression component.
 * To evaluate an expression, a function taking as parameters all tuple
 * attributes is created. Then the function is evaluated with the
 * attribute values from the tuple.
 * 
 * Thread safety:
 * 
 * Immutable class so there are no thread safety issues. 
 * 
 * @author TCSDESIGNER
 */
public class MathExpressionConstraint implements TupleConstraint {
	
	/**
	 * The expression that is used to test the tuple.
	 * Cannot be null, empty or all spaces.
	 * Set in the constructor, used in validate.
	 */    
	private String expression = null;
	
	/**
	 * Constructor. Copies the param to the attribute.
	 * 
	 * @param expression the expression to test the tuple
	 * 
	 * @throws IllegalArgumentException if the argument is null, empty string or all spaces
	 */
	public MathExpressionConstraint(String expression) {
	}
	
	/**
	 * Getter for the test expression (expression field).
	 *  
	 * @return the expression
	 */
	public String getExpression() {
		return null;
	}

	/**
	 * Checks whether the tuple respects the constraint.
	 * 
	 * Implementation details:
	 * 
	 * - MathEval me = new MathEval()
	 * - obtain comma separated tuple atribute name list
	 * - me.define("f(" + attributeList + ")->" + expression)
	 * - obtain comma separated tuple value list (toString is used)
	 * - me.evaluate("f(" + valueList + ")")) should return a boolean result
	 * 
	 * @param tuple the tuple to check
	 * 
	 * @return true if constraint is met, false otherwise
	 * 
	 * @throws IllegalArgumentException if the argument is null
	 * @throws EvaluationException thrown if the evaluation cannot be done because of an
	 * implementation specific error 
	 */
	public boolean validate(Tuple tuple) throws IllegalArgumentException, EvaluationException {
		return false;
	}

}
