package com.topcoder.persistence.relation.constraints;

import com.topcoder.persistence.relation.EvaluationException;
import com.topcoder.persistence.relation.Tuple;
import com.topcoder.persistence.relation.TupleConstraint;

/**
 * This class represents a constraint that aggregates the results of two or 
 * more other constraints. The aggregation is an OR aggregation meaning
 * that the constraint is true if any of the contained constraints is true.
 * 
 * Thread safety:
 * 
 * Immutable class so there are no thread safety issues. 
 * 
 * @author TCSDESIGNER
 */
public class OrConstraint implements TupleConstraint {
	
	/**
	 * The aggregated constraints.
	 * Cannot be null, contain nulls or have less that 2 elements.
	 * Set in the constructor, used in the methods.
	 */
	public TupleConstraint[] constraints = null;
	
	/**
	 * Constructor. Creates an array from the two constaints.
	 * 
	 * @param leftConstraint the left constraint
	 * @param rightConstraint the right constraint.
	 * 
	 * @throws IllegalArgumentException if any argument is null
	 */
	public OrConstraint(TupleConstraint leftConstraint, TupleConstraint rightConstraint) throws IllegalArgumentException {
	}

	/**
	 * Constructor. Copies the array to the attribute (defensive copy).
	 * 
	 * @param constraints the aggregated constraints
	 * 
	 * @throws IllegalArgumentException if the argument is null, has nulls or size is less than 2
	 */
	public OrConstraint(TupleConstraint[] constraints) throws IllegalArgumentException {
	}
	
	/**
	 * Getter for the aggregated constraints (constraints field).
	 * 
	 * @return the aggregated constraints
	 */
	public TupleConstraint[] getConstraints() {
		return null;
	}

	/**
	 * Checks whether the tuple respects the constraint.
	 * 
	 * Implementation details:
	 * 
	 * - iterate constraints and call validate on them
	 * - if one returns true, true is returned immediately
	 * - otherwise false is returned.
	 * 
	 * @param tuple the tuple to check
	 * 
	 * @return true if constraint is met, false otherwise
	 * 
	 * @throws IllegalArgumentException if the argument is null
	 * @throws EvaluationException thrown if the evaluation cannot be done because of an
	 * implementation specific error 
	 */
	public boolean validate(Tuple tuple) throws IllegalArgumentException, EvaluationException {
		return false;
	}

}
